#include <XSContainer.h>
#include <XSFit/Fit/ParallelStats.h>
#include <XSFit/Fit/Fit.h>
#include <XSFit/Fit/StatManager.h>
#include <XSUtil/Error/Error.h>

void ParallelStats::execute(const bool isParallel, const TransferStruct& input,
                        TransferStruct& output)
{
   using namespace XSContainer;
   
   // Assume input parameter values have been verified to
   //  fall within allowed range.
   const std::vector<double>& parValuesVec = input.dValues[0];
   output.status=-1;
   if (parValuesVec.size())
   {
      RealArray parValues(&parValuesVec[0],parValuesVec.size());
      fit->setVariableParameterValues(parValues, 'v');
      fit->statManager()->performStats();
      Real newStatVal = fit->statistic();

      output.dValues.clear();
      output.dValues.push_back(std::vector<double>(1, newStatVal));
      output.status=0;
      // the following lines ensure that any periodic input values will be
      // altered to lie within the primary period range and included in the output.
      parValues = fit->variableParameterValues('v');
      std::vector<double> tmpVec;
      for (size_t i=0; i<parValues.size(); i++) tmpVec.push_back(parValues[i]);
      output.dValues.push_back(tmpVec);
   }
   else
      throw YellowAlert();
}
